Class: Google::Cloud::VideoIntelligence::V1p3beta1::ObjectTrackingAnnotation
- Inherits:
-
Object
- Object
- Google::Cloud::VideoIntelligence::V1p3beta1::ObjectTrackingAnnotation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb
Overview
Annotations corresponding to one tracked object.
Instance Attribute Summary collapse
-
#confidence ⇒ ::Float
Object category's labeling confidence of this track.
-
#entity ⇒ ::Google::Cloud::VideoIntelligence::V1p3beta1::Entity
Entity to specify the object category that this track is labeled as.
-
#frames ⇒ ::Array<::Google::Cloud::VideoIntelligence::V1p3beta1::ObjectTrackingFrame>
Information corresponding to all frames where this object track appears.
-
#segment ⇒ ::Google::Cloud::VideoIntelligence::V1p3beta1::VideoSegment
Non-streaming batch mode ONLY.
-
#track_id ⇒ ::Integer
Streaming mode ONLY.
Instance Attribute Details
#confidence ⇒ ::Float
894 895 896 897 |
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 894 class ObjectTrackingAnnotation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entity ⇒ ::Google::Cloud::VideoIntelligence::V1p3beta1::Entity
894 895 896 897 |
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 894 class ObjectTrackingAnnotation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#frames ⇒ ::Array<::Google::Cloud::VideoIntelligence::V1p3beta1::ObjectTrackingFrame>
894 895 896 897 |
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 894 class ObjectTrackingAnnotation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#segment ⇒ ::Google::Cloud::VideoIntelligence::V1p3beta1::VideoSegment
894 895 896 897 |
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 894 class ObjectTrackingAnnotation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#track_id ⇒ ::Integer
894 895 896 897 |
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 894 class ObjectTrackingAnnotation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |