Class: Google::Cloud::VideoIntelligence::V1p3beta1::StreamingAnnotateVideoRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb

Overview

The top-level message sent by the client for the StreamingAnnotateVideo method. Multiple StreamingAnnotateVideoRequest messages are sent. The first message must only contain a StreamingVideoConfig message. All subsequent messages must only contain input_content data.

Instance Attribute Summary collapse

Instance Attribute Details

#input_content::String

Returns The video data to be annotated. Chunks of video data are sequentially sent in StreamingAnnotateVideoRequest messages. Except the initial StreamingAnnotateVideoRequest message containing only video_config, all subsequent AnnotateStreamingVideoRequest messages must only contain input_content field. Note: as with all bytes fields, protobuffers use a pure binary representation (not base64).

Note: The following fields are mutually exclusive: input_content, video_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The video data to be annotated. Chunks of video data are sequentially sent in StreamingAnnotateVideoRequest messages. Except the initial StreamingAnnotateVideoRequest message containing only video_config, all subsequent AnnotateStreamingVideoRequest messages must only contain input_content field. Note: as with all bytes fields, protobuffers use a pure binary representation (not base64).

    Note: The following fields are mutually exclusive: input_content, video_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



943
944
945
946
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 943

class StreamingAnnotateVideoRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#video_config::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingVideoConfig

Returns Provides information to the annotator, specifing how to process the request. The first AnnotateStreamingVideoRequest message must only contain a video_config message.

Note: The following fields are mutually exclusive: video_config, input_content. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingVideoConfig)

    Provides information to the annotator, specifing how to process the request. The first AnnotateStreamingVideoRequest message must only contain a video_config message.

    Note: The following fields are mutually exclusive: video_config, input_content. If a field in that set is populated, all other fields in the set will automatically be cleared.



943
944
945
946
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 943

class StreamingAnnotateVideoRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end