Class: Google::Cloud::VideoIntelligence::V1p3beta1::StreamingVideoConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb

Overview

Provides information to the annotator that specifies how to process the request.

Instance Attribute Summary collapse

Instance Attribute Details

#automl_action_recognition_config::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingAutomlActionRecognitionConfig

Returns Config for STREAMING_AUTOML_ACTION_RECOGNITION.

Note: The following fields are mutually exclusive: automl_action_recognition_config, shot_change_detection_config, label_detection_config, explicit_content_detection_config, object_tracking_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingAutomlActionRecognitionConfig)

    Config for STREAMING_AUTOML_ACTION_RECOGNITION.

    Note: The following fields are mutually exclusive: automl_action_recognition_config, shot_change_detection_config, label_detection_config, explicit_content_detection_config, object_tracking_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



991
992
993
994
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 991

class StreamingVideoConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#automl_classification_config::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingAutomlClassificationConfig

Returns Config for STREAMING_AUTOML_CLASSIFICATION.

Note: The following fields are mutually exclusive: automl_classification_config, shot_change_detection_config, label_detection_config, explicit_content_detection_config, object_tracking_config, automl_action_recognition_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingAutomlClassificationConfig)

    Config for STREAMING_AUTOML_CLASSIFICATION.

    Note: The following fields are mutually exclusive: automl_classification_config, shot_change_detection_config, label_detection_config, explicit_content_detection_config, object_tracking_config, automl_action_recognition_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



991
992
993
994
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 991

class StreamingVideoConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#automl_object_tracking_config::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingAutomlObjectTrackingConfig

Returns Config for STREAMING_AUTOML_OBJECT_TRACKING.

Note: The following fields are mutually exclusive: automl_object_tracking_config, shot_change_detection_config, label_detection_config, explicit_content_detection_config, object_tracking_config, automl_action_recognition_config, automl_classification_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingAutomlObjectTrackingConfig)

    Config for STREAMING_AUTOML_OBJECT_TRACKING.

    Note: The following fields are mutually exclusive: automl_object_tracking_config, shot_change_detection_config, label_detection_config, explicit_content_detection_config, object_tracking_config, automl_action_recognition_config, automl_classification_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



991
992
993
994
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 991

class StreamingVideoConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#explicit_content_detection_config::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingExplicitContentDetectionConfig

Returns Config for STREAMING_EXPLICIT_CONTENT_DETECTION.

Note: The following fields are mutually exclusive: explicit_content_detection_config, shot_change_detection_config, label_detection_config, object_tracking_config, automl_action_recognition_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingExplicitContentDetectionConfig)

    Config for STREAMING_EXPLICIT_CONTENT_DETECTION.

    Note: The following fields are mutually exclusive: explicit_content_detection_config, shot_change_detection_config, label_detection_config, object_tracking_config, automl_action_recognition_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



991
992
993
994
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 991

class StreamingVideoConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#feature::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingFeature

Returns Requested annotation feature.

Returns:



991
992
993
994
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 991

class StreamingVideoConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#label_detection_config::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingLabelDetectionConfig

Returns Config for STREAMING_LABEL_DETECTION.

Note: The following fields are mutually exclusive: label_detection_config, shot_change_detection_config, explicit_content_detection_config, object_tracking_config, automl_action_recognition_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingLabelDetectionConfig)

    Config for STREAMING_LABEL_DETECTION.

    Note: The following fields are mutually exclusive: label_detection_config, shot_change_detection_config, explicit_content_detection_config, object_tracking_config, automl_action_recognition_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



991
992
993
994
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 991

class StreamingVideoConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#object_tracking_config::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingObjectTrackingConfig

Returns Config for STREAMING_OBJECT_TRACKING.

Note: The following fields are mutually exclusive: object_tracking_config, shot_change_detection_config, label_detection_config, explicit_content_detection_config, automl_action_recognition_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingObjectTrackingConfig)

    Config for STREAMING_OBJECT_TRACKING.

    Note: The following fields are mutually exclusive: object_tracking_config, shot_change_detection_config, label_detection_config, explicit_content_detection_config, automl_action_recognition_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



991
992
993
994
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 991

class StreamingVideoConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#shot_change_detection_config::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingShotChangeDetectionConfig

Returns Config for STREAMING_SHOT_CHANGE_DETECTION.

Note: The following fields are mutually exclusive: shot_change_detection_config, label_detection_config, explicit_content_detection_config, object_tracking_config, automl_action_recognition_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingShotChangeDetectionConfig)

    Config for STREAMING_SHOT_CHANGE_DETECTION.

    Note: The following fields are mutually exclusive: shot_change_detection_config, label_detection_config, explicit_content_detection_config, object_tracking_config, automl_action_recognition_config, automl_classification_config, automl_object_tracking_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



991
992
993
994
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 991

class StreamingVideoConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#storage_config::Google::Cloud::VideoIntelligence::V1p3beta1::StreamingStorageConfig

Returns Streaming storage option. By default: storage is disabled.

Returns:



991
992
993
994
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 991

class StreamingVideoConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end