Class: Google::Cloud::VideoIntelligence::V1p3beta1::TextFrame

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb

Overview

Video frame level annotation results for text annotation (OCR). Contains information regarding timestamp and bounding box locations for the frames containing detected OCR text snippets.

Instance Attribute Summary collapse

Instance Attribute Details

#rotated_bounding_box ⇒ ::Google::Cloud::VideoIntelligence::V1p3beta1::NormalizedBoundingPoly



837
838
839
840
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 837

class TextFrame
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#time_offset ⇒ ::Google::Protobuf::Duration



837
838
839
840
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 837

class TextFrame
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end