Class: Google::Cloud::VideoIntelligence::V1p3beta1::WordInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb

Overview

Word-specific information for recognized words. Word information is only included in the response when certain request parameters are set, such as enable_word_time_offsets.

Instance Attribute Summary collapse

Instance Attribute Details

#confidence ⇒ ::Float (readonly)



768
769
770
771
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 768

class WordInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_time ⇒ ::Google::Protobuf::Duration



768
769
770
771
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 768

class WordInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#speaker_tag ⇒ ::Integer (readonly)



768
769
770
771
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 768

class WordInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time ⇒ ::Google::Protobuf::Duration



768
769
770
771
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 768

class WordInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#word ⇒ ::String



768
769
770
771
# File 'proto_docs/google/cloud/videointelligence/v1p3beta1/video_intelligence.rb', line 768

class WordInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end